@@ -10,14 +10,17 @@ from dataclasses import dataclass
 from pathlib import Path
 from typing import Iterator, List, Optional, Tuple, Type, Union
 
+import rpm
+
 from specfile.changelog import Changelog, ChangelogEntry
 from specfile.exceptions import SourceNumberException, SpecfileException
 from specfile.macro_definitions import MacroDefinition, MacroDefinitions
+from specfile.macros import Macro, Macros
 from specfile.prep import Prep
-from specfile.rpm import Macros, SpecParser
 from specfile.sections import Section, Sections
 from specfile.sourcelist import Sourcelist
 from specfile.sources import Patches, Sources
+from specfile.spec_parser import SpecParser
 from specfile.tags import Tag, Tags
 from specfile.value_parser import SUBSTITUTION_GROUP_PREFIX, ValueParser
 
@@ -31,8 +34,10 @@ class Specfile:
         sourcedir: Path to sources and patches.
         autosave: Whether to automatically save any changes made.
         macros: List of extra macro definitions.
-        ignore_missing_includes: Whether to attempt to parse the spec file even if one
-          or more files to be included using the %include directive are not available.
+        force_parse: Whether to attempt to parse the spec file even if one or more
+          sources required to be present at parsing time are not available.
+          Such sources include sources referenced from shell expansions
+          in tag values and sources included using the %include directive.
     """
 
     def __init__(
@@ -41,13 +46,13 @@ class Specfile:
         sourcedir: Optional[Union[Path, str]] = None,
         autosave: bool = False,
         macros: Optional[List[Tuple[str, str]]] = None,
-        ignore_missing_includes: bool = False,
+        force_parse: bool = False,
     ) -> None:
         self.path = Path(path)
         self.autosave = autosave
         self._lines = self.path.read_text().splitlines()
         self._parser = SpecParser(
-            Path(sourcedir or self.path.parent), macros, ignore_missing_includes
+            Path(sourcedir or self.path.parent), macros, force_parse
         )
         self._parser.parse(str(self))
 
@@ -56,8 +61,8 @@ class Specfile:
         sourcedir = repr(self._parser.sourcedir)
         autosave = repr(self.autosave)
         macros = repr(self._parser.macros)
-        ignore_missing_includes = repr(self._parser.ignore_missing_includes)
-        return f"Specfile({path}, {sourcedir}, {autosave}, {macros}, {ignore_missing_includes})"
+        force_parse = repr(self._parser.force_parse)
+        return f"Specfile({path}, {sourcedir}, {autosave}, {macros}, {force_parse})"
 
     def __str__(self) -> str:
         return "\n".join(self._lines) + "\n"
@@ -84,21 +89,27 @@ class Specfile:
         return self._parser.macros
 
     @property
-    def ignore_missing_includes(self) -> bool:
+    def force_parse(self) -> bool:
         """
-        Whether to attempt to parse the spec file even if one or more files
-        to be included using the %include directive are not available.
+        Whether to attempt to parse the spec file even if one or more
+        sources required to be present at parsing time are not available.
         """
-        return self._parser.ignore_missing_includes
+        return self._parser.force_parse
 
     @property
     def tainted(self) -> bool:
         """
-        Indication that the spec file wasn't parsed completely and at least
-        one file to be included was ignored.
+        Indication that parsing of the spec file was forced and one or more
+        sources required to be present at parsing time were not available
+        and were replaced with dummy files.
         """
         return self._parser.tainted
 
+    @property
+    def rpm_spec(self) -> rpm.spec:
+        """Underlying `rpm.spec` instance."""
+        return self._parser.spec
+
     def reload(self) -> None:
         """Reload the spec file content."""
         self._lines = self.path.read_text().splitlines()
@@ -124,6 +135,19 @@ class Specfile:
         self._parser.parse(str(self), extra_macros)
         return Macros.expand(expression)
 
+    def get_active_macros(self) -> List[Macro]:
+        """
+        Gets active macros in the context of the spec file.
+
+        This includes built-in RPM macros, macros loaded from macro files
+        and macros defined in the spec file itself.
+
+        Returns:
+            List of `Macro` objects.
+        """
+        self._parser.parse(str(self))
+        return Macros.dump()
+
     @contextlib.contextmanager
     def lines(self) -> Iterator[List[str]]:
         """
