@@ -6,71 +6,9 @@ import itertools
 import re
 from typing import Any, Iterable, List, Optional, SupportsIndex, Union, cast, overload
 
+from specfile.constants import TAG_NAMES, TAGS_WITH_ARG
 from specfile.sections import Section
 
-# valid tag names as defined in build/parsePreamble.c in RPM source
-TAG_NAMES = {
-    "name",
-    "version",
-    "release",
-    "epoch",
-    "summary",
-    "license",
-    "distribution",
-    "disturl",
-    "vendor",
-    "group",
-    "packager",
-    "url",
-    "vcs",
-    "source",
-    "patch",
-    "nosource",
-    "nopatch",
-    "excludearch",
-    "exclusivearch",
-    "excludeos",
-    "exclusiveos",
-    "icon",
-    "provides",
-    "requires",
-    "recommends",
-    "suggests",
-    "supplements",
-    "enhances",
-    "prereq",
-    "conflicts",
-    "obsoletes",
-    "prefixes",
-    "prefix",
-    "buildroot",
-    "buildarchitectures",
-    "buildarch",
-    "buildconflicts",
-    "buildprereq",
-    "buildrequires",
-    "autoreqprov",
-    "autoreq",
-    "autoprov",
-    "docdir",
-    "disttag",
-    "bugurl",
-    "translationurl",
-    "upstreamreleases",
-    "orderwithrequires",
-    "removepathpostfixes",
-    "modularitylabel",
-}
-
-# tags that can optionally have an argument (language or qualifier)
-TAGS_WITH_ARG = {
-    "summary",
-    "group",
-    "requires",
-    "prereq",
-    "orderwithrequires",
-}
-
 
 def get_tag_name_regex(name: str) -> str:
     """Contructs regex corresponding to the specified tag name."""
@@ -297,6 +235,14 @@ class Tag:
             f"'{self._separator}', {comments})"
         )
 
+    @property
+    def normalized_name(self) -> str:
+        """
+        Normalized name of the tag. The first character is capitalized
+        and the rest lowercased.
+        """
+        return self.name.capitalize()
+
     @property
     def valid(self) -> bool:
         """Validity of the tag. A tag is valid if it 'survives' the expansion of the spec file."""
